@@ -125,7 +125,7 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if (value.find(matcher) >= 0) != expected_result:
+        if self.__hamcrest_assert_that(value, matchers.contains_string(matcher)) != expected_result:
             self._error(field, f"Must be a string {not_}containing '{matcher}', but was '{value}'")
 
     def _validate_starts_with(self, matcher, field, value):
@@ -134,7 +134,7 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if value.startswith(matcher) != expected_result:
+        if self.__hamcrest_assert_that(value, matchers.starts_with(matcher)) != expected_result:
             self._error(field, f"Must be a string {not_}starts with '{matcher}', but was '{value}'")
 
     def _validate_ends_with(self, matcher, field, value):
@@ -143,7 +143,7 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if value.endswith(matcher) != expected_result:
+        if self.__hamcrest_assert_that(value, matchers.ends_with(matcher)) != expected_result:
             self._error(field, f"Must be a string {not_}ends with '{matcher}', but was '{value}'")
 
     def _validate_string_contains_in_order(self, matcher, field, value):
@@ -162,7 +162,7 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if (value.lower() == matcher.lower()) != expected_result:
+        if self.__hamcrest_assert_that(value, matchers.equal_to_ignoring_case(matcher)) != expected_result:
             self._error(field, f"Must be a string {not_}equal to '{matcher}' ignoring case, but was '{value}'")
 
     # -------- List Length ----------------------------------------------------------------
